@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2021 Julius Künzel <jk.kdedev@smartlab.uber.space>
+    SPDX-FileCopyrightText: 2021 Julius Künzel <julius.kuenzel@kde.org>
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
@@ -46,7 +46,6 @@ UrlListParamWidget::UrlListParamWidget(std::shared_ptr<AssetParameterModel> mode
         m_knsbutton->hide();
     }
     // setup the name
-    m_labelName->setText(m_model->data(m_index, Qt::DisplayRole).toString());
     m_isLutList = m_model->getAssetId().startsWith(QLatin1String("avfilter.lut3d"));
     UrlListParamWidget::slotRefresh();
 
@@ -144,7 +143,7 @@ void UrlListParamWidget::slotRefresh()
 
         // check for Kdenlive installed luts files
         QStringList customLuts = QStandardPaths::locateAll(QStandardPaths::AppLocalDataLocation, QStringLiteral("luts"), QStandardPaths::LocateDirectory);
-        for (const QString &folderpath : qAsConst(customLuts)) {
+        for (const QString &folderpath : std::as_const(customLuts)) {
             QDir dir(folderpath);
             QDirIterator it(dir.absolutePath(), m_fileExt, QDir::Files, QDirIterator::Subdirectories);
             while (it.hasNext()) {
@@ -168,7 +167,7 @@ void UrlListParamWidget::slotRefresh()
         QDir dir = QFileInfo(currentValue).absoluteDir();
         if (dir.exists()) {
             QStringList entrys = dir.entryList(m_fileExt, QDir::Files);
-            for (const auto &filename : qAsConst(entrys)) {
+            for (const auto &filename : std::as_const(entrys)) {
                 values.append(dir.filePath(filename));
             }
             // make sure the current value is added. If it is a duplicate we remove it later
@@ -184,7 +183,7 @@ void UrlListParamWidget::slotRefresh()
     QMap<QString, QString> entryMap;
     int ix = 0;
     // Put all name/value combinations in a map
-    for (const QString &value : qAsConst(values)) {
+    for (const QString &value : std::as_const(values)) {
         if (m_isLutList) {
             if (value.toLower().endsWith(QLatin1String(".cube")) && !KdenliveSettings::validated_luts().contains(value)) {
                 // Open LUT file and check validity
@@ -205,10 +204,10 @@ void UrlListParamWidget::slotRefresh()
                 // Duplicate name, add a suffix
                 const QString baseName = lumaName;
                 int i = 2;
-                lumaName = baseName + QString(" / %1").arg(i);
+                lumaName = baseName + QStringLiteral(" / %1").arg(i);
                 while (entryMap.contains(lumaName)) {
                     i++;
-                    lumaName = baseName + QString(" / %1").arg(i);
+                    lumaName = baseName + QStringLiteral(" / %1").arg(i);
                 }
             }
             entryMap.insert(lumaName, value);
@@ -258,11 +257,7 @@ void UrlListParamWidget::slotRefresh()
         }
     }
     if (!thumbnailsToBuild.isEmpty() && !m_watcher.isRunning()) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        m_thumbJob = QtConcurrent::run(this, &UrlListParamWidget::buildThumbnails, thumbnailsToBuild);
-#else
         m_thumbJob = QtConcurrent::run(&UrlListParamWidget::buildThumbnails, this, thumbnailsToBuild);
-#endif
         m_watcher.setFuture(m_thumbJob);
     }
 }
