@@ -74,11 +74,7 @@ protected:
     void mouseReleaseEvent(QMouseEvent *event) override;
     void mouseMoveEvent(QMouseEvent *event) override;
     void focusInEvent(QFocusEvent *event) override;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     void enterEvent(QEnterEvent *event) override;
-#else
-    void enterEvent(QEvent *event) override;
-#endif
     void leaveEvent(QEvent *event) override;
     void dropEvent(QDropEvent *event) override;
 
@@ -110,11 +106,7 @@ protected:
     void mouseReleaseEvent(QMouseEvent *event) override;
     void mouseMoveEvent(QMouseEvent *event) override;
     void focusInEvent(QFocusEvent *event) override;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     void enterEvent(QEnterEvent *) override;
-#else
-    void enterEvent(QEvent *event) override;
-#endif
     void leaveEvent(QEvent *event) override;
 
 protected Q_SLOTS:
@@ -211,7 +203,7 @@ public:
     void emitItemUpdated(std::shared_ptr<AbstractProjectItem> item);
 
     /** @brief Open a producer in the clip monitor */
-    void openProducer(std::shared_ptr<ProjectClip> controller);
+    void openProducer(std::shared_ptr<ProjectClip> controller, const QUuid &sequenceUuid = QUuid());
     void openProducer(std::shared_ptr<ProjectClip> controller, int in, int out);
 
     /** @brief Get a clip from it's id */
@@ -336,8 +328,6 @@ public:
     /** @brief Update a sequence AV info (has audio/video) */
     void updateSequenceAVType(const QUuid &uuid, int tracksCount);
 
-    // TODO refac: remove this and call directly the function in ProjectItemModel
-    void cleanupUnused();
     void selectAll();
     /** @brief Save an mlt playlist from a bin id and a list of cuts
      * @param binId the id of the source clip for zones
@@ -385,6 +375,8 @@ public:
     const QString binInfoToString() const;
     /** @brief Load info (root folder, view type) from a string */
     const QString loadInfo(const QStringList binInfo, const QStringList existingNames);
+    /** @brief Display a clip effect stack */
+    void showItemEffectStack(ObjectId owner);
 
 private Q_SLOTS:
     void slotAddClip();
@@ -467,7 +459,7 @@ public Q_SLOTS:
     void slotCreateProjectClip();
     void slotEditClipCommand(const QString &id, const QMap<QString, QString> &oldProps, const QMap<QString, QString> &newProps);
     /** @brief Start a filter job requested by a filter applied in timeline */
-    void slotStartFilterJob(const ItemInfo &info, const QString &id, QMap<QString, QString> &filterParams, QMap<QString, QString> &consumerParams,
+    void slotStartFilterJob(/*const ItemInfo &info,*/ const QString &id, QMap<QString, QString> &filterParams, QMap<QString, QString> &consumerParams,
                             QMap<QString, QString> &extraParams);
     void slotItemDropped(const QStringList ids, const QModelIndex parent);
     const QString slotUrlsDropped(const QList<QUrl> urls, const QModelIndex parent);
@@ -484,9 +476,10 @@ public Q_SLOTS:
     void slotUpdateClipProperties(const QString &id, const QMap<QString, QString> &properties, bool refreshPropertiesPanel);
     /** @brief Add effect to active Bin clip (used when double clicking an effect in list). */
     void slotAddEffect(std::vector<QString> ids, const QStringList &effectData);
-    void slotExpandUrl(const ItemInfo &info, const QString &url, QUndoCommand *command);
+    void slotExpandUrl(/*const ItemInfo &info,*/ const QString &url, QUndoCommand *command);
     /** @brief Abort all ongoing operations to prepare close. */
     void abortOperations();
+    void doDisplaySimpleMessage(const QString &text, KMessageWidget::MessageType type);
     void doDisplayMessage(const QString &text, KMessageWidget::MessageType type, const QList<QAction *> &actions = QList<QAction *>(), bool showCloseButton = false, BinMessage::BinCategory messageCategory = BinMessage::BinCategory::NoMessage);
     void doDisplayMessage(const QString &text, KMessageWidget::MessageType type, const QString logInfo);
     /** @brief Select a clip in the Bin from its id. */
@@ -643,7 +636,7 @@ Q_SIGNALS:
     void requesteInvalidRemoval(const QString &, const QString &, const QString &);
     /** @brief Analysis data changed, refresh panel. */
     void updateAnalysisData(const QString &);
-    void openClip(std::shared_ptr<ProjectClip> c, int in = -1, int out = -1);
+    void openClip(std::shared_ptr<ProjectClip> c, int in = -1, int out = -1, const QUuid sequenceUuid = QUuid());
     /** @brief Fill context menu with occurrences of this clip in timeline. */
     void findInTimeline(const QString &, QList<int> ids = QList<int>());
     void clipNameChanged(int, const QString);
