@@ -109,7 +109,7 @@ const QStringList MarkerListModel::categoriesToStringList() const
     QMapIterator<int, Core::MarkerCategory> i(pCore->markerTypes);
     while (i.hasNext()) {
         i.next();
-        categories << QString("%1:%2:%3").arg(i.value().displayName, QString::number(i.key()), i.value().color.name());
+        categories << QStringLiteral("%1:%2:%3").arg(i.value().displayName, QString::number(i.key()), i.value().color.name());
     }
     return categories;
 }
@@ -126,7 +126,7 @@ QStringList MarkerListModel::guideCategoriesToStringList(const QString &categori
         return categories;
     }
     auto list = json.array();
-    for (const auto &entry : qAsConst(list)) {
+    for (const auto &entry : std::as_const(list)) {
         if (!entry.isObject()) {
             qDebug() << "Warning : Skipping invalid category data";
             continue;
@@ -139,7 +139,7 @@ QStringList MarkerListModel::guideCategoriesToStringList(const QString &categori
         int ix = entryObj[QLatin1String("index")].toInt();
         QString comment = entryObj[QLatin1String("comment")].toString();
         QString color = entryObj[QLatin1String("color")].toString();
-        categories << QString("%1:%2:%3").arg(comment, QString::number(ix), color);
+        categories << QStringLiteral("%1:%2:%3").arg(comment, QString::number(ix), color);
     }
     return categories;
 }
@@ -717,7 +717,7 @@ bool MarkerListModel::importFromJson(const QString &data, bool ignoreConflicts,
         return false;
     }
     auto list = json.array();
-    for (const auto &entry : qAsConst(list)) {
+    for (const auto &entry : std::as_const(list)) {
         if (!entry.isObject()) {
             qDebug() << "Warning : Skipping invalid marker data";
             continue;
