@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2022 Julius Künzel <jk.kdedev@smartlab.uber.space>
+    SPDX-FileCopyrightText: 2022 Julius Künzel <julius.kuenzel@kde.org>
 
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
@@ -505,7 +505,11 @@ RenderPresetDialog::RenderPresetDialog(QWidget *parent, RenderPresetModel *prese
         }
         slotUpdateParams();
     });
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+    connect(fixedGop, &QCheckBox::checkStateChanged, this, &RenderPresetDialog::slotUpdateParams);
+#else
     connect(fixedGop, &QCheckBox::stateChanged, this, &RenderPresetDialog::slotUpdateParams);
+#endif
     connect(bFramesSpinner, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &RenderPresetDialog::slotUpdateParams);
     connect(additionalParams, &QPlainTextEdit::textChanged, this, &RenderPresetDialog::slotUpdateParams);
 
@@ -837,7 +841,7 @@ void RenderPresetDialog::slotUpdateParams()
     QString addionalParams = additionalParams->toPlainText().simplified();
 
     QStringList removed;
-    for (const auto &p : qAsConst(m_uiParams)) {
+    for (const auto &p : std::as_const(m_uiParams)) {
         QString store = addionalParams;
         if (store != addionalParams.remove(QRegularExpression(QStringLiteral("((^|\\s)%1=\\S*)").arg(p)))) {
             removed.append(p);
