@@ -412,7 +412,7 @@ bool DocumentChecker::hasErrorInProject()
 
     // Check existence of luma files
     QStringList filesToCheck = getAssetsFilesByMltTag(m_doc, QStringLiteral("transition"), getLumaPairs());
-    for (const QString &lumafile : qAsConst(filesToCheck)) {
+    for (const QString &lumafile : std::as_const(filesToCheck)) {
         QString filePath = ensureAbsolutePath(lumafile);
 
         if (QFile::exists(filePath)) {
@@ -470,7 +470,7 @@ bool DocumentChecker::hasErrorInProject()
 
     // Check for missing transitions (eg. not installed)
     QStringList transtions = getAssetsServiceIds(m_doc, QStringLiteral("transition"));
-    for (const QString &id : qAsConst(transtions)) {
+    for (const QString &id : std::as_const(transtions)) {
         if (!TransitionsRepository::get()->exists(id) && !itemsContain(MissingType::Transition, id, MissingStatus::Remove)) {
             DocumentResource item;
             item.type = MissingType::Transition;
@@ -482,7 +482,7 @@ bool DocumentChecker::hasErrorInProject()
 
     // Check for missing filter assets
     QStringList assetsToCheck = getAssetsFilesByMltTag(m_doc, QStringLiteral("filter"), getAssetPairs());
-    for (const QString &filterfile : qAsConst(assetsToCheck)) {
+    for (const QString &filterfile : std::as_const(assetsToCheck)) {
         QString filePath = ensureAbsolutePath(filterfile);
 
         if (QFile::exists(filePath)) {
@@ -512,7 +512,7 @@ bool DocumentChecker::hasErrorInProject()
     // Check for missing effects (eg. not installed)
     QStringList filters = getAssetsServiceIds(m_doc, QStringLiteral("filter"));
     QStringList renamedEffectNames = renamedEffects.keys();
-    for (const QString &id : qAsConst(filters)) {
+    for (const QString &id : std::as_const(filters)) {
         if (!EffectsRepository::get()->exists(id) && !itemsContain(MissingType::Effect, id, MissingStatus::Remove)) {
             // m_missingFilters << id;
             if (renamedEffectNames.contains(id) && EffectsRepository::get()->exists(renamedEffects.value(id))) {
@@ -1039,7 +1039,7 @@ QString DocumentChecker::getMissingProducers(QDomElement &e, const QDomNodeList
                 return original;
             }
         }
-        bool isPreviewChunk = QFileInfo(resource).absolutePath().endsWith(QString("/%1/preview").arg(m_documentid));
+        bool isPreviewChunk = QFileInfo(resource).absolutePath().endsWith(QStringLiteral("/%1/preview").arg(m_documentid));
         // Missing clip found, make sure to omit timeline preview
         if (!isPreviewChunk) {
             checkClip(e, resource);
@@ -1532,7 +1532,7 @@ void DocumentChecker::fixTitleFont(const QDomNodeList &producers, const QString
             QString xml = Xml::getXmlProperty(e, QStringLiteral("xmldata"));
             QStringList fonts = TitleWidget::extractFontList(xml);
             if (fonts.contains(oldFont)) {
-                xml.replace(QString("font=\"%1\"").arg(oldFont), QString("font=\"%1\"").arg(newFont));
+                xml.replace(QStringLiteral("font=\"%1\"").arg(oldFont), QStringLiteral("font=\"%1\"").arg(newFont));
                 Xml::setXmlProperty(e, QStringLiteral("xmldata"), xml);
                 Xml::setXmlProperty(e, QStringLiteral("force_reload"), QStringLiteral("2"));
                 Xml::setXmlProperty(e, QStringLiteral("_fullreload"), QStringLiteral("2"));
@@ -1846,7 +1846,6 @@ QString DocumentChecker::readableNameForMissingType(MissingType type)
 {
     switch (type) {
     case MissingType::Clip:
-    case MissingType::MissingBinClip:
         return i18n("Clip");
     case MissingType::TitleFont:
         return i18n("Title Font");
@@ -1862,6 +1861,8 @@ QString DocumentChecker::readableNameForMissingType(MissingType type)
         return i18n("Effect");
     case MissingType::Transition:
         return i18n("Transition");
+    case MissingType::MissingBinClip:
+        return i18n("Unreferenced clip");
     case MissingType::CircularRef:
         return i18n("Corrupted sequence");
     default:
