@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2017 Nicolas Carion
-    SPDX-FileCopyrightText: 2022 Julius Künzel <jk.kdedev@smartlab.uber.space>
+    SPDX-FileCopyrightText: 2022 Julius Künzel <julius.kuenzel@kde.org>
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
@@ -99,7 +99,7 @@ void RenderPresetRepository::refresh(bool fullRefresh)
         fileList.removeAll(QStringLiteral("customprofiles.xml"));
     }
     // Parse files downloaded with KNewStuff
-    for (const QString &filename : qAsConst(fileList)) {
+    for (const QString &filename : std::as_const(fileList)) {
         parseFile(directory.absoluteFilePath(filename), true);
     }
 
@@ -157,9 +157,6 @@ void RenderPresetRepository::parseFile(const QString &exportFile, bool editable)
                 return;
             }
             QTextStream out(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            out.setCodec("UTF-8");
-#endif
             out << newdoc.toString();
             file.close();
             // now that we fixed the file, run this function again
@@ -231,7 +228,7 @@ void RenderPresetRepository::parseMltPresets()
         const QStringList profiles = root.entryList(QDir::Files, QDir::Name);
         for (const QString &prof : profiles) {
             std::unique_ptr<RenderPresetModel> model(
-                new RenderPresetModel(groupName, root.absoluteFilePath(prof), prof, QString("properties=lossless/" + prof), true));
+                new RenderPresetModel(groupName, root.absoluteFilePath(prof), prof, QStringLiteral("properties=lossless/%1").arg(prof), true));
             if (m_profiles.count(model->name()) == 0) {
                 m_groups.append(model->groupName());
                 m_groups.removeDuplicates();
@@ -242,9 +239,9 @@ void RenderPresetRepository::parseMltPresets()
     if (root.cd(QStringLiteral("../stills"))) {
         QString groupName = i18nc("Category Name", "Images sequence");
         QStringList profiles = root.entryList(QDir::Files, QDir::Name);
-        for (const QString &prof : qAsConst(profiles)) {
+        for (const QString &prof : std::as_const(profiles)) {
             std::unique_ptr<RenderPresetModel> model(
-                new RenderPresetModel(groupName, root.absoluteFilePath(prof), prof, QString("properties=stills/" + prof), false));
+                new RenderPresetModel(groupName, root.absoluteFilePath(prof), prof, QStringLiteral("properties=stills/%1").arg(prof), false));
             m_groups.append(model->groupName());
             m_groups.removeDuplicates();
             m_profiles.insert(std::make_pair(model->name(), std::move(model)));
@@ -375,9 +372,6 @@ const QString RenderPresetRepository::savePreset(RenderPresetModel *preset, bool
         return {};
     }
     QTextStream out(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    out.setCodec("UTF-8");
-#endif
     out << doc.toString();
     if (file.error() != QFile::NoError) {
         KMessageBox::error(nullptr, i18n("Cannot write to file %1", file.fileName()));
@@ -410,7 +404,7 @@ bool RenderPresetRepository::deletePreset(const QString &name, bool dontRefresh)
     QString exportFile = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + QStringLiteral("/export/customprofiles.xml");
     QDomDocument doc;
     QFile file(exportFile);
-    doc.setContent(&file, false);
+    doc.setContent(&file);
     file.close();
 
     QDomElement documentElement;
@@ -434,9 +428,6 @@ bool RenderPresetRepository::deletePreset(const QString &name, bool dontRefresh)
         return false;
     }
     QTextStream out(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    out.setCodec("UTF-8");
-#endif
     out << doc.toString();
     if (file.error() != QFile::NoError) {
         KMessageBox::error(nullptr, i18n("Cannot write to file %1", exportFile));
